MatrixDecomposedValues class

Constructors

MatrixDecomposedValues(Offset translation, double scale, double rotation)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rotation → double
Rotation in radians, (-pi..pi) range.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
Scaling factor.
final
translation → Offset
Translation, in most cases useful only for matrices that are nothing but a translation (no scale and no rotation).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited